@@ -1,15 +1,16 @@
 package String::Indent::Join;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-31'; # DATE
-our $DIST = 'Bencher-Scenarios-StringFunctions'; # DIST
-our $VERSION = '0.005'; # VERSION
-
 #use 5.010001;
 use strict;
 use warnings;
 
 use Exporter;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-27'; # DATE
+our $DIST = 'Bencher-Scenarios-StringFunctions'; # DIST
+our $VERSION = '0.006'; # VERSION
+
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        indent
@@ -42,7 +43,7 @@ String::Indent::Join - String indenting routines
 
 =head1 VERSION
 
-This document describes version 0.005 of String::Indent::Join (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2021-07-31.
+This document describes version 0.006 of String::Indent::Join (from Perl distribution Bencher-Scenarios-StringFunctions), released on 2022-03-27.
 
 =head1 FUNCTIONS
 
@@ -56,14 +57,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Sc
 
 Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-StringFunctions>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-StringFunctions>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<String::Indent>, L<String::Nudge>
@@ -72,11 +65,36 @@ L<String::Indent>, L<String::Nudge>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-StringFunctions>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
